@@ -61,6 +61,7 @@ class PubMedArticle(MetaPubObject):
         
         # shared between book and article types:
         self.pmid = self._get_pmid()
+        self.url  = self._get_url()
         self.authors = self._get_authors() if pmt=='article' else self._get_book_authors()
         self.title = self._get_title() if pmt=='article' else self._get_book_articletitle()
         self.authors_str = self._get_authors_str()
@@ -149,7 +150,7 @@ class PubMedArticle(MetaPubObject):
         return [ _au_to_last_fm(au) for au in self.content.findall('BookDocument/Book/AuthorList/Author') ]
 
     def _get_book_abstracts(self):
-        abd = {}
+        abd = OrderedDict()
         for item in self.content.findall('BookDocument/Abstract/AbstractText'):
             abd[item.get('Label')] = item.text
         return abd
@@ -200,6 +201,9 @@ class PubMedArticle(MetaPubObject):
     def _get_pmid(self):
         return self._get(self._root+'/PMID')
 
+    def _get_url(self):
+        return 'http://ncbi.nlm.nih.gov/pubmed/'+str(self.pmid)
+
     def _get_abstract(self):
         abstracts = self.content.findall(self._root + '/Article/Abstract/AbstractText')
         if abstracts == []:
@@ -209,7 +213,7 @@ class PubMedArticle(MetaPubObject):
             return abstracts[0].text
 
         # this is a type of PMA with several AbstractText listings (like a Book)
-        abd = {}
+        abd = OrderedDict()
         for ab in abstracts:
             abd[ab.get('Label')] = ab.text
         return '\n'.join(['%s: %s' % (k,v) for k,v in abd.items()])
